@@ -7,7 +7,6 @@ import click
 
 from ._completion_classes import completion_init
 from ._completion_shared import Shells, _get_shell_name, get_completion_script, install
-from .core import HAS_SHELLINGHAM
 from .models import ParamMeta
 from .params import Option
 from .utils import get_params_from_function
@@ -18,7 +17,7 @@ _click_patched = False
 def get_completion_inspect_parameters() -> tuple[ParamMeta, ParamMeta]:
     completion_init()
     test_disable_detection = os.getenv("_TYPER_COMPLETE_TEST_DISABLE_SHELL_DETECTION")
-    if HAS_SHELLINGHAM and not test_disable_detection:
+    if not test_disable_detection:
         parameters = get_params_from_function(_install_completion_placeholder_function)
     else:
         parameters = get_params_from_function(
